/* $Id: insertxmp.java,v 1.6 2014/09/04 08:23:30 rp Exp $
 *
 * PDFlib PLOP: PDF Linearization, Optimization, Protection
 * mini sample for inserting XMP metadata in PDF documents
 */

import java.io.*;
import com.pdflib.PLOPException;
import com.pdflib.plop;

public class insertxmp
{
    public static void main (String argv[])
    {
	plop plop = null;

	try {

	    /* Directory where files will be searched */
	    final String searchpath = "../data";

	    /* input document */
	    final String in_filename = "PLOP-datasheet.pdf";
	    /* output document */
	    final String out_filename = "PLOP-datasheet-xmp.pdf";

	    /* Option list for the generated output document.
	     * Some alternatives for the option list using the supplied XMP
	     * samples:
	     *
	     * Insert custom metadata for the GWG (Ghent Workgroup)
	     * Ad Ticket scheme (see http://www.gwg.org/Jobtickets.phtml):
	     * "metadata={filename=gwg_ad_ticket.xmp validate=xmp2004}"
	     *
	     * Insert custom metadata based on Acme's enterprise schema:
	     * "metadata={filename=acme.xmp}"
	     *
	     * Insert a custom "engineering" schema for scanned documents:
	     * This works best with a PDF/A-1 input document (e.g.
	     * mini_pdfa1.pdf), and requires XMP input which conforms to
	     * PDF/A-1:
	     * "metadata={filename=engineering.xmp}"
	     *
	     * Insert a PDF/A extension schema after validating the XMP for
	     * PDF/A-1.
	     * This works best with a PDF/A-1 input document (e.g.
	     * mini_pdfa1.pdf), and requires XMP input which conforms to
	     * PDF/A-1:
	     * "metadata={filename=machine_pdfa1.xmp validate=pdfa1}"
	     *
	     */
	    final String base_opts = "metadata={filename=gwg_ad_ticket.xmp}";

	    String optlist;
	    int doc;

	    plop = new plop();

	    optlist = "searchpath={" + searchpath + "}";
	    plop.set_option(optlist);

	    /* create a new PLOP object */
	    if ((doc = plop.open_document(in_filename, "")) == -1){
		System.err.println("Error: " + plop.get_errmsg());
		plop.delete();
		System.exit(2);
	    }

	    /* create the output file and add XMP metadata */
	    if (plop.create_document(out_filename, base_opts + " input=" + doc) == -1) {
		System.err.println("Error: " + plop.get_errmsg());
		plop.delete();
		System.exit(2);
	    }

	    /* close input files */
	    plop.close_document(doc, "");

        } catch (PLOPException e) {
            System.err.print("PLOP exception occurred in insertxmp");
            System.err.print("[" + e.get_errnum() + "] " + e.get_apiname() +
                            ": " + e.get_errmsg() + "\n");
        } catch (Exception e) {
            System.err.println(e.getMessage());
	} finally {
	    /* delete the PLOP object */
	    if (plop != null) plop.delete();
	}
    }
}
