#!/usr/bin/perl
# $Id: sign.pl,v 1.22 2014/09/05 13:55:24 rp Exp $
#
# PDFlib PLOP DS:
# Demonstrate mass signature with optional PKCS#11 session handling
#

use PDFlib::PLOP 5.0;

my $doc;
# create a new PLOP object
my $plop = new PDFlib::PLOP;

# Basic signature options 
$sign_opts =
    "sigtype=cms " .     # use sigtype=cades for PAdES signature 
    "ltv=try " .         # use ltv=full to ensure LTV status 
    # when using PKCS11 use
    # "engine=pkcs#11 digitalid={filename=cryptoki.dll} "
    "engine=builtin digitalid={filename=demorsa2048.p12} password={demo} " ;

# This is where input files live. Adjust as necessary.
my $searchpath = "../data";

#  Set to 1 to enable PKCS11 session handling
$PKCS11 = 0;

if ($#ARGV <1){
    die("usage: sign <infile> ...\n");
}

eval {
    my $optlist;
    $plop->set_option("searchpath={${searchpath}}");

    if ($plop->prepare_signature($sign_opts) == -1)
    {
	die("Error: ", $plop->get_apiname(), ": ", $plop->get_errmsg(), "\n");
    }

    for ($i =0; $i<=$#ARGV; $i++){
	printf("Signing '%s'...\n", $ARGV[$i]);
	if (($doc = $plop->open_document($ARGV[$i], "")) == -1)
	{
	    printf("Error: %s: %s\n", $plop->get_apiname(), $plop->get_errmsg());
	    next;
	}

	$signed_name = sprintf("%s-signed.pdf", $ARGV[$i]);

	$optlist = sprintf("input=%d", $doc);
	if ($plop->create_document($signed_name, $optlist) == -1)
	{
	    printf("Error: %s: %s\n", $plop->get_apiname(), $plop->get_errmsg());
	    if ($PKCS11){
		# The PKCS#11 session may have expired;
		# restart and try again.
		if ($plop->prepare_signature($sign_opts) == -1)
		{
		    die("Error: ", $plop->get_apiname(), ": ", $plop->get_errmsg(), "\n");
		}

		$optlist = sprintf("input=%d", $doc);
		if ($plop->create_document($signed_name, $optlist) == -1)
		{
		    die("Error: ", $plop->get_apiname(), ": ", $plop->get_errmsg(), "\n");
		}
	    }
	}

	$plop->close_document($doc, "");
    }
};

if ($@) {
    die("$0: PLOP Exception occurred:\n$@");
}
