<?php
# $Id: hellosign.php,v 1.18 2014/09/08 08:37:18 rp Exp $
#
# PDFlib PLOP: PDF Linearization, Optimization, Protection
# hellosign sample: generate a document in memory with PDFlib, and sign it
# with PLOP
#

# This is where input files live. Adjust as necessary.
$searchpath = "{../data} {../../data}";

$out_filename = "hellosign.pdf";

# Basic signature options
$sign_opts =
    "sigtype=cms " .    /* use sigtype=cades for PAdES signature */
    "ltv=try " .        /* use ltv=full to ensure LTV status */
    /* use the following line for PKCS11 usage
    "engine=pkcs#11 digitalid={filename=cryptoki.dll} "
    */
    "engine=builtin digitalid={filename=demorsa2048.p12} password={demo} " ;


# ------------- Step 1: generate document in memory  with PDFlib ------------
try {
    $p = new PDFlib();

    # create a new PDF document in memory

    $p->begin_document("", "");

    $p->set_info("Creator", "hellosign.php");
    $p->set_info("Author", "Rainer Plckl");
    $p->set_info("Title", "Hello, world/signed (PHP)!");

    $font = $p->load_font("Helvetica-Bold", "host", "");

    $p->begin_page_ext(595, 842, "");

    $p->setfont($font, 24);
    $p->set_text_pos(50, 700);
    $p->show("Hello, world/signed!");
    $p->continue_text("(says PHP)");
    $p->end_page_ext("");

    $p->end_document("");

    # fetch the memory buffer containing the PDF document
    $contents = $p->get_buffer();

# ------------------ Step 2: sign the document -----------------
    
    $plop = new PLOP();


    $plop->set_option("searchpath={{$searchpath}}");


    # Create a virtual PVF file from the document data in memory
    $plop->create_pvf("/pvf/hello.pdf", $contents, "");

    # open unsigned input document from PVF file
    if (($doc = $plop->open_document("/pvf/hello.pdf", "")) == 0)
    {
        die("Error: " . $plop->get_apiname() . ": "
                                 . $plop->get_errmsg() . "\n");
    }

    if ($plop->prepare_signature( $sign_opts) == 0)
    {
        die("Error: " . $plop->get_apiname() . ": "
                                 . $plop->get_errmsg() . "\n");
    }

    # sign the output file
    if ($plop->create_document($out_filename, "input=" . $doc) == 0)
    {
        die("Error: " . $plop->get_apiname() . ": "
                                 . $plop->get_errmsg() . "\n");
    }

    # close the input document
    $plop->close_document($doc, "");

    # delete PVF file containing input document
    if ($plop->delete_pvf("/pvf/hello.pdf") == 0)
    {
	die("Error: %s\n" .  $plop->get_errmsg());
    }

}
catch (PLOPException $e) {
    die("PLOP exception occurred in hellosign sample:\n" .
	"[" . $e->get_errnum() . "] " . $e->get_apiname() . ": " .
	$e->get_errmsg() . "\n");
    }
catch (Exception $e) {
    die($e);
}

$p = 0;
header("text/html");
print "<a href=\"$out_filename\">click here</a> to open the signed PDF file";
?>
