# PDFlib PLOP DS:
# Demonstrate mass signature with optional PKCS#11 session handling
#
# $Id: multisign.py,v 1.1 2014/09/08 12:42:45 rp Exp $

from sys import *
from traceback import print_tb
from PDFlib.PLOP import *

# Basic signature options 

# use sigtype=cades for PAdES signature 
# use ltv=full to ensure LTV status
# for  use with PKCS11
# "engine=pkcs#11 digitalid={filename=cryptoki.dll} "
sign_opts = \
    "sigtype=cms " \
    "ltv=try " \
    "engine=builtin digitalid={filename=demorsa2048.p12} password={demo} "
    

# This is where input files live. Adjust as necessary.
searchpath = "../data"

# Set to 1 to enable PKCS11 session handling
PKCS11 = 0

if len(argv) < 2:
    raise Exception("usage: multisign <infile> ..\n." )

# create a new PLOP object
plop = PLOP()

try:
    optlist = "searchpath={%s}" % searchpath
    plop.set_option(optlist)

    if (plop.prepare_signature(sign_opts) == -1):
        raise PLOPException("Error: %s: %s" % (plop.get_apiname(),
                                                 plop.get_errmsg()))

    for i in range (1, len(argv), 1):
        print("Signing '%s' ..." % argv[i])
        doc = plop.open_document(argv[i], "")
        if (doc == -1):
            print("Error: %s: %s" % (plop.get_apiname(),
                                                     plop.get_errmsg()))
            continue

        signed_name = argv[i] + "-signed.pdf"
        optlist = "input={%d}" % doc

        if (plop.create_document(signed_name, optlist) == -1):
            print("Error: %s: %s" % (plop.get_apiname(),
                                                     plop.get_errmsg()))

        if (PKCS11 == 1):
            # The PKCS#11 session may have expired;
            # restart and try again.
            if (plop.prepare_signature(sign_opts) == -1):
                raise PLOPException("Error: %s: %s" % (plop.get_apiname(),
                                                         plop.get_errmsg()))

            if (plop.create_document(signed_name, optlist) == -1):
                raise PLOPException("Error: %s: %s" % (plop.get_apiname(),
                                                         plop.get_errmsg()))

        plop.close_document(doc, "")

except PLOPException:
    print("PDFlib PLOP exception occurred:\n[%d] %s: %s" %
        ((plop.get_errnum()), plop.get_apiname(), plop.get_errmsg()))
    print_tb(exc_info()[2])

except Exception:
    print("Exception occurred: %s" % (exc_info()[0]))
    print_tb(exc_info()[2])

finally:
    plop.delete()
